@@ -1,20 +1,13 @@
 //! `libafl_targets` contains runtime code, injected in the target itself during compilation.
 
+#[macro_use]
+extern crate alloc;
+
 include!(concat!(env!("OUT_DIR"), "/constants.rs"));
 
-#[cfg(any(
-    feature = "sancov_pcguard_edges",
-    feature = "sancov_pcguard_hitcounts",
-    feature = "sancov_pcguard_edges_ptr",
-    feature = "sancov_pcguard_hitcounts_ptr"
-))]
+#[cfg(any(feature = "sancov_pcguard_edges", feature = "sancov_pcguard_hitcounts",))]
 pub mod sancov_pcguard;
-#[cfg(any(
-    feature = "sancov_pcguard_edges",
-    feature = "sancov_pcguard_hitcounts",
-    feature = "sancov_pcguard_edges_ptr",
-    feature = "sancov_pcguard_hitcounts_ptr"
-))]
+#[cfg(any(feature = "sancov_pcguard_edges", feature = "sancov_pcguard_hitcounts",))]
 pub use sancov_pcguard::*;
 
 #[cfg(any(feature = "sancov_cmplog", feature = "sancov_value_profile"))]
@@ -27,6 +20,11 @@ pub mod libfuzzer;
 #[cfg(feature = "libfuzzer")]
 pub use libfuzzer::*;
 
+#[cfg(feature = "sancov_8bit")]
+pub mod sancov_8bit;
+#[cfg(feature = "sancov_8bit")]
+pub use sancov_8bit::*;
+
 pub mod coverage;
 pub use coverage::*;
 
@@ -36,4 +34,5 @@ pub use value_profile::*;
 pub mod cmplog;
 pub use cmplog::*;
 
+#[cfg(feature = "std")]
 pub mod drcov;
